@@ -13,12 +13,13 @@ _SECRETS_DIR_KEYS_TRUSTDB="${_SECRETS_DIR_KEYS}/trustdb.gpg"
 
 _SECRETS_DIR_PATHS_MAPPING="${_SECRETS_DIR_PATHS}/mapping.cfg"
 
-# _SECRETS_VERBOSE is expected to be empty or '1'.
-# Empty means 'off', any other value means 'on'.
+
 # shellcheck disable=SC2153
 if [[ -n "$SECRETS_VERBOSE" ]] && [[ "$SECRETS_VERBOSE" -ne 0 ]]; then
-    # shellcheck disable=SC2034
-    _SECRETS_VERBOSE='1'
+  # shellcheck disable=SC2034
+  _SECRETS_VERBOSE='1'
+  # _SECRETS_VERBOSE is empty or '1'. 
+  # Empty means 'off', any other value means 'on'.
 fi
 
 : "${SECRETS_EXTENSION:=".secret"}"
@@ -29,11 +30,11 @@ fi
 : "${SECRETS_OCTAL_PERMS_COMMAND:="_os_based __get_octal_perms"}"
 : "${SECRETS_EPOCH_TO_DATE:="_os_based __epoch_to_date"}"
 
-# Temp Dir
+# Temp Dir:
 : "${TMPDIR:=/tmp}"
 
 # AWK scripts:
-# shellcheck disable=2016
+# shellcheck disable=SC2016
 AWK_FSDB_HAS_RECORD='
 BEGIN { FS=":"; OFS=":"; cnt=0; }
 {
@@ -45,7 +46,7 @@ BEGIN { FS=":"; OFS=":"; cnt=0; }
 END { if ( cnt > 0 ) print "0"; else print "1"; }
 '
 
-# shellcheck disable=2016
+# shellcheck disable=SC2016
 AWK_FSDB_RM_RECORD='
 BEGIN { FS=":"; OFS=":"; }
 {
@@ -56,7 +57,7 @@ BEGIN { FS=":"; OFS=":"; }
 }
 '
 
-# shellcheck disable=2016
+# shellcheck disable=SC2016
 AWK_FSDB_CLEAR_HASHES='
 BEGIN { FS=":"; OFS=":"; }
 {
@@ -64,7 +65,7 @@ BEGIN { FS=":"; OFS=":"; }
 }
 '
 
-# shellcheck disable=2016
+# shellcheck disable=SC2016
 AWK_GPG_VER_CHECK='
 /^gpg/{
   version=$3
@@ -103,6 +104,7 @@ GPG_VER_MIN_21="$($SECRETS_GPG_COMMAND --version | gawk "$AWK_GPG_VER_CHECK")"
 
 # Bash:
 
+# echos 0 if function exists, otherwise non-zero
 function _function_exists {
   local function_name="$1" # required
 
@@ -131,6 +133,10 @@ function _os_based {
       "$1_linux" "${@:2}"
     ;;
 
+    MSYS*)
+      "$1_linux" "${@:2}"
+    ;;
+
     CYGWIN*)
       "$1_linux" "${@:2}"
     ;;
@@ -181,20 +187,6 @@ function _set_config {
 }
 
 
-function _file_has_line {
-  # First parameter is the key, second is the filename.
-
-  local key="$1" # required
-  local filename="$2" # required
-
-  local contains
-  contains=$(grep -qw "$key" "$filename"; echo $?)
-
-  # 0 on contains, 1 for error.
-  echo "$contains"
-}
-
-
 # this sets the global variable 'temporary_filename'
 # currently this function is only used by 'hide'
 function _temporary_file {
@@ -202,7 +194,7 @@ function _temporary_file {
   # which will be removed on system exit.
   temporary_filename=$(_os_based __temp_file)  # is not `local` on purpose.
 
-  trap 'if [[ -f "$temporary_filename" ]]; then if [[ -n "$_SECRETS_VERBOSE" ]] || [[ -n "$SECRETS_TEST_VERBOSE" ]]; then echo "git-secret: cleaning up: $temporary_filename"; fi; rm -f "$temporary_filename"; fi;' EXIT
+  trap 'if [[ -f "$temporary_filename" ]]; then if [[ -n "$_SECRETS_VERBOSE" ]] || [[ "$SECRETS_TEST_VERBOSE" == 1 ]]; then echo "git-secret: cleaning up: $temporary_filename"; fi; rm -f "$temporary_filename"; fi;' EXIT
 }
 
 
@@ -320,7 +312,7 @@ function _maybe_create_gitignore {
   # This function creates '.gitignore' if it was missing.
 
   local full_path
-  full_path=$(_append_root_path '.gitignore')
+  full_path=$(_prepend_root_path '.gitignore')
 
   if [[ ! -f "$full_path" ]]; then
     touch "$full_path"
@@ -337,9 +329,9 @@ function _add_ignored_file {
   _maybe_create_gitignore
 
   local full_path
-  full_path=$(_append_root_path '.gitignore')
+  full_path=$(_prepend_root_path '.gitignore')
 
-  printf '%q' "$filename" >> "$full_path"
+  printf '%q\n' "$filename" >> "$full_path"
 }
 
 
@@ -380,7 +372,7 @@ function _get_git_root_path {
 
 # Relative paths:
 
-function _append_root_path {
+function _prepend_root_path {
   # This function adds root path to any other path.
 
   local path="$1" # required
@@ -392,28 +384,45 @@ function _append_root_path {
 }
 
 
+# if passed a name like 'filename.txt', returns a full path in the repo
+# For #710: if we are in a subdir, fixup the path with the subdir
+function _prepend_relative_root_path {
+  local path="$1" # required
+
+  local full_path
+  full_path=$(_prepend_root_path "$path")
+
+  local subdir
+  subdir=$(git rev-parse --show-prefix)   # get the subdir of repo, like "subdir/"
+  if [ -n "$subdir" ]; then
+    full_path="$(dirname "$full_path")/${subdir}/$(basename "$full_path")"
+  fi
+
+  echo "$full_path"
+}
+
 function _get_secrets_dir {
-  _append_root_path "${_SECRETS_DIR}"
+  _prepend_root_path "${_SECRETS_DIR}"
 }
 
 
 function _get_secrets_dir_keys {
-  _append_root_path "${_SECRETS_DIR_KEYS}"
+  _prepend_root_path "${_SECRETS_DIR_KEYS}"
 }
 
 
 function _get_secrets_dir_path {
-  _append_root_path "${_SECRETS_DIR_PATHS}"
+  _prepend_root_path "${_SECRETS_DIR_PATHS}"
 }
 
 
 function _get_secrets_dir_keys_trustdb {
-  _append_root_path "${_SECRETS_DIR_KEYS_TRUSTDB}"
+  _prepend_root_path "${_SECRETS_DIR_KEYS_TRUSTDB}"
 }
 
 
 function _get_secrets_dir_paths_mapping {
-  _append_root_path "${_SECRETS_DIR_PATHS_MAPPING}"
+  _prepend_root_path "${_SECRETS_DIR_PATHS_MAPPING}"
 }
 
 
@@ -460,36 +469,23 @@ function _warn_or_abort {
 }
 
 
-function _find_and_clean {
-  # required:
-  local pattern="$1" # can be any string pattern
+function _find_and_remove_secrets_formatted {
+  local filenames
+  _list_all_added_files # sets array variable 'filenames'
 
-  local verbose_opt=''
-  if [[ -n "$_SECRETS_VERBOSE" ]]; then
-    verbose_opt='v';
-  fi
-
-  local root
-  root=$(_get_git_root_path)
-
-  # shellcheck disable=2086
-  find "$root" -path "$pattern" -type f -print0 | xargs -0 rm -f$verbose_opt
+  for filename in "${filenames[@]}"; do
+    local path # absolute path
+    encrypted_filename=$(_get_encrypted_filename "$filename")
+    if [[ -f "$encrypted_filename" ]]; then
+      rm "$encrypted_filename"
+      if [[ -n "$_SECRETS_VERBOSE" ]]; then
+        echo "git-secret: deleted: $encrypted_filename"
+      fi
+    fi
+  done
 }
 
 
-function _find_and_clean_formatted {
-  # required:
-  local pattern="$1" # can be any string pattern
-
-  local outputs
-  outputs=$(_find_and_clean "$pattern")
-
-  if [[ -n "$_SECRETS_VERBOSE" ]] && [[ -n "$outputs" ]]; then
-    # shellcheck disable=SC2001
-    echo "$outputs" | sed "s/^/git-secret: cleaning: /"
-  fi
-}
-
 
 # this sets the global array variable 'filenames'
 function _list_all_added_files {
@@ -497,7 +493,7 @@ function _list_all_added_files {
   path_mappings=$(_get_secrets_dir_paths_mapping)
 
   if [[ ! -s "$path_mappings" ]]; then
-    _abort "$path_mappings is missing."
+    _abort "path_mappings file is missing or empty: $path_mappings"
   fi
 
   local filename
@@ -535,7 +531,7 @@ function _secrets_dir_is_not_ignored {
   ignores=$(_check_ignore "$git_secret_dir")
 
   if [[ ! $ignores -eq 1 ]]; then
-    _abort "'$git_secret_dir' is in .gitignore"
+    _abort "entry already in .gitignore: $git_secret_dir"
   fi
 }
 
@@ -634,6 +630,14 @@ function _assert_keyring_doesnt_contain_emails {
   _assert_keyring_emails "$homedir" "$keyring_name" "$emails" 0
 }
 
+function _assert_keyring_contains_emails_at_least_once {
+  local homedir=$1
+  local keyring_name=$2
+  local emails=$3
+  _assert_keyring_emails "$homedir" "$keyring_name" "$emails" 1 1 # expect the email at least once in the keyring
+}
+
+
 
 function _assert_keyring_emails {
   local homedir="$1"
@@ -643,6 +647,7 @@ function _assert_keyring_emails {
   # 0 to not expect the email in the keyring;
   # 1 to expect the email in the keyring
   local expected="$4"
+  local allow_duplicates=$5 # set this to 0 to not allow duplicate emails in the keyring when processing assertion (optional)
 
   local gpg_uids
   gpg_uids=$(_get_users_in_gpg_keyring "$homedir")
@@ -660,7 +665,9 @@ function _assert_keyring_emails {
         if [[ $emails_found -eq 0 ]]; then
           _abort "no key found in gpg $keyring_name for: $email"
         elif [[ $emails_found -gt 1 ]]; then
-          _abort "$emails_found keys found in gpg $keyring_name for: $email"
+          if [[ $allow_duplicates -ne 1 ]]; then
+            _abort "$emails_found keys found in gpg $keyring_name for: $email"
+          fi
         fi
     else
         if [[ $emails_found -gt 0 ]]; then
@@ -696,15 +703,15 @@ function _get_users_in_gpg_keyring {
   result=$($SECRETS_GPG_COMMAND "${args[@]}" --no-permission-warning --list-public-keys --with-colon --fixed-list-mode | \
       gawk -F: '$1=="uid"' )
 
+  local emails
+  emails=$(_extract_emails_from_gpg_output "$result")
+
   # For #508 / #552: warn user if gpg indicates keys are one of:
   # i=invalid, d=disabled, r=revoked, e=expired, n=not valid
   # See https://github.com/gpg/gnupg/blob/master/doc/DETAILS#field-2---validity # for more on gpg 'validity codes'.
   local invalid_lines
   invalid_lines=$(echo "$result" | gawk -F: '$2=="i" || $2=="d" || $2=="r" || $2=="e" || $2=="n"')
 
-  local emails
-  emails=$(_extract_emails_from_gpg_output "$result")
-
   local emails_with_invalid_keys
   emails_with_invalid_keys=$(_extract_emails_from_gpg_output "$invalid_lines")
 
@@ -767,53 +774,59 @@ function _decrypt {
   local encrypted_filename
   encrypted_filename=$(_get_encrypted_filename "$filename")
 
-  local args=( "--use-agent" "--decrypt" "--no-permission-warning" )
-
-  if [[ "$write_to_file" -eq 1 ]]; then
-    args+=( "-o" "$filename" )
-  fi
-
-  if [[ "$force" -eq 1 ]]; then
-    args+=( "--yes" )
-  fi
-
-  if [[ -n "$homedir" ]]; then
-    args+=( "--homedir" "$homedir" )
-  fi
-
-  if [[ "$GPG_VER_MIN_21" -eq 1 ]]; then
-    if [[ -n "$SECRETS_PINENTRY" ]]; then
-      args+=( "--pinentry-mode" "$SECRETS_PINENTRY" )
-    else
-      args+=( "--pinentry-mode" "loopback" )
-    fi
-  fi
-
-  if [[ -z "$_SECRETS_VERBOSE" ]]; then
-    args+=( "--quiet" )
-  fi
-
-  set +e   # disable 'set -e' so we can capture exit_code
-
-  #echo "# gpg passphrase: $passphrase" >&3
-  local exit_code
-  if [[ -n "$passphrase" ]]; then
-    echo "$passphrase" | $SECRETS_GPG_COMMAND "${args[@]}" --batch --yes --no-tty --passphrase-fd 0 \
-      "$encrypted_filename"
-    exit_code=$?
+  if [ ! -f "$encrypted_filename" ]; then
+    _warn_or_abort "cannot find file to decrypt: $encrypted_filename" "1" "$error_ok"
   else
-    $SECRETS_GPG_COMMAND "${args[@]}" "$encrypted_filename"
-    exit_code=$?
-  fi
-
-  set -e  # re-enable set -e
-
-  # note that according to https://github.com/sobolevn/git-secret/issues/238 ,
-  # it's possible for gpg to return a 0 exit code but not have decrypted the file
-  #echo "# gpg exit code: $exit_code, error_ok: $error_ok" >&3
-  if [[ "$exit_code" -ne "0" ]]; then
-    local msg="problem decrypting file with gpg: exit code $exit_code: $filename"
-    _warn_or_abort "$msg" "$exit_code" "$error_ok"
+    local args=( "--use-agent" "--decrypt" )
+  
+    if [[ "$write_to_file" -eq 1 ]]; then
+      args+=( "-o" "$filename" )
+    fi
+  
+    if [[ "$force" -eq 1 ]]; then
+      args+=( "--yes" )
+    fi
+  
+    if [[ -n "$homedir" ]]; then
+      args+=( "--homedir" "$homedir" )
+    fi
+  
+    if [[ "$GPG_VER_MIN_21" -eq 1 ]]; then
+      if [[ -n "$SECRETS_PINENTRY" ]]; then
+        args+=( "--pinentry-mode" "$SECRETS_PINENTRY" )
+      else
+        args+=( "--pinentry-mode" "loopback" )
+      fi
+    fi
+  
+    if [[ -z "$_SECRETS_VERBOSE" ]]; then
+      # we no longer use --no-permission-warning here, for #811
+      args+=( "--quiet" )
+    fi
+  
+    set +e   # disable 'set -e' so we can capture exit_code
+  
+    #echo "# gpg passphrase: $passphrase" >&3
+    local exit_code
+    if [[ -n "$passphrase" ]]; then
+      exec 5<<<"$passphrase"  # use 5, because descriptors 3 and 4 are used by bats
+      $SECRETS_GPG_COMMAND "${args[@]}" --batch --yes --no-tty --passphrase-fd 5 "$encrypted_filename"
+      exit_code=$?
+      exec 5>&-   # close file descriptor 5
+    else
+      $SECRETS_GPG_COMMAND "${args[@]}" "$encrypted_filename"
+      exit_code=$?
+    fi
+  
+    set -e  # re-enable set -e
+  
+    # note that according to https://github.com/sobolevn/git-secret/issues/238 ,
+    # it's possible for gpg to return a 0 exit code but not have decrypted the file
+    #echo "# gpg exit code: $exit_code, error_ok: $error_ok" >&3
+    if [[ "$exit_code" -ne "0" ]]; then
+      local msg="problem decrypting file with gpg: exit code $exit_code: $filename"
+      _warn_or_abort "$msg" "$exit_code" "$error_ok"
+    fi
   fi
 
   # at this point the file should be written to disk or output to stdout
