@@ -2,12 +2,11 @@
 
 
 function add {
-  local auto_ignore=1
   OPTIND=1
 
   while getopts "ihv" opt; do
     case "$opt" in
-      i) auto_ignore=1;;    # this doesn't change anything
+      i) ;;    # this doesn't change anything
 
       h) _show_manual_for "add";;
 
@@ -32,7 +31,7 @@ function add {
     local path # absolute path
     local normalized_path # relative to the .git dir
     normalized_path=$(_git_normalize_filename "$item")
-    path=$(_append_root_path "$normalized_path")
+    path=$(_prepend_root_path "$normalized_path")
 
     # check that the file is not tracked
     local in_git
@@ -59,25 +58,13 @@ function add {
   # Are there any unignored files?
 
   if [[ ! "${#not_ignored[@]}" -eq 0 ]]; then
-    # And show them all at once.
-    local message
-    message="these files are not in .gitignore: $*"
+    # Add these files to `.gitignore` automatically:
+    # see https://github.com/sobolevn/git-secret/issues/18 for more.
 
-    if [[ "$auto_ignore" -eq 0 ]]; then
-      # This file is not ignored. user don't want it to be added automatically.
-      # Raise the exception, since all files, which will be hidden, must be ignored.
-      # note that it is no longer possible to wind up in this code path as auto_ignore cannot be 0.
-      # code left here in case we want to restore/modify this path later
-      _abort "$message"
-    else
-      # In this case these files should be added to the `.gitignore` automatically:
-      # see https://github.com/sobolevn/git-secret/issues/18 for more.
-      _message "$message"
-      _message "auto adding them to .gitignore"
-      for item in "${not_ignored[@]}"; do
-        _add_ignored_file "$item"
-      done
-    fi
+    for item in "${not_ignored[@]}"; do
+      _message "file not in .gitignore, adding: $item"
+      _add_ignored_file "$item"
+    done
   fi
 
   # Adding files to path mappings:
@@ -101,7 +88,7 @@ function add {
        if [[ -n "$_SECRETS_VERBOSE" ]]; then
         _message "adding file: $key"
       fi
-      
+
       ((count=count+1))
     fi
   done
