@@ -32,7 +32,7 @@ function cat {
     local path
 
     filename=$(_get_record_filename "$line")
-    path=$(_append_root_path "$filename")
+    path=$(_prepend_relative_root_path "$filename")  # this uses the _relative version because of #710
 
     # The parameters are: filename, write-to-file, force, homedir, passphrase
     _decrypt "$path" "0" "0" "$homedir" "$passphrase"
