@@ -4,7 +4,7 @@
 function clean {
   OPTIND=1
 
-  # shellcheck disable=2034
+  # shellcheck disable=SC2034
   while getopts 'vh' opt; do
     case "$opt" in
       v) _SECRETS_VERBOSE=1;;
@@ -18,12 +18,11 @@ function clean {
   shift $((OPTIND-1))
   [ "$1" = '--' ] && shift
 
-  if [ $# -ne 0 ]; then 
+  if [ $# -ne 0 ]; then
     _abort "clean does not understand params: $*"
   fi
 
   _user_required
 
-  # User should see properly formatted output:
-  _find_and_clean_formatted "*$SECRETS_EXTENSION"
+  _find_and_remove_secrets_formatted
 }
