@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 
-# shellcheck disable=2016
+# shellcheck disable=SC2016
 AWK_FSDB_UPDATE_HASH='
 BEGIN { FS=":"; OFS=":"; }
 {
@@ -15,14 +15,6 @@ BEGIN { FS=":"; OFS=":"; }
 }
 '
 
-function _optional_clean {
-  local clean="$1"
-
-  if [[ $clean -eq 1 ]]; then
-    _find_and_clean_formatted "*$SECRETS_EXTENSION"
-  fi
-}
-
 
 function _optional_delete {
   local delete="$1"
@@ -33,19 +25,19 @@ function _optional_delete {
 
     # We use custom formatting here:
     if [[ -n "$_SECRETS_VERBOSE" ]]; then
-      echo && _message 'removing unencrypted files:'
+      _message 'removing unencrypted files'
     fi
 
-    while read -r line; do
-      # So the formatting would not be repeated several times here:
+    while read -r line; do  # each line is a record like: filename: or filename:hash
       local filename
       filename=$(_get_record_filename "$line")
-      _find_and_clean "*$filename"
+      if [[ -e "$filename" ]]; then 
+        rm "$filename"
+        if [[ -n "$_SECRETS_VERBOSE" ]]; then
+          _message "deleted: $filename"
+        fi
+      fi
     done < "$path_mappings"
-
-    if [[ -n "$_SECRETS_VERBOSE" ]]; then
-      echo
-    fi
   fi
 }
 
@@ -108,16 +100,18 @@ function hide {
   shift $((OPTIND-1))
   [ "$1" = '--' ] && shift
 
-  if [ $# -ne 0 ]; then 
+  if [ $# -ne 0 ]; then
     _abort "hide does not understand params: $*"
   fi
 
   # We need user to continue:
   _user_required
 
-  # If -c option was provided, it would clean the hidden files
+  # If -c option was provided, clean the hidden files
   # before creating new ones.
-  _optional_clean "$clean"
+  if [[ $clean -eq 1 ]]; then
+    _find_and_remove_secrets_formatted
+  fi
 
   # Encrypting files:
 
@@ -149,8 +143,8 @@ function hide {
 
     local input_path
     local output_path
-    input_path=$(_append_root_path "$filename")
-    output_path=$(_append_root_path "$encrypted_filename")
+    input_path=$(_prepend_root_path "$filename")
+    output_path=$(_prepend_root_path "$encrypted_filename")
 
     # Checking that file is valid:
     if [[ ! -f "$input_path" ]]; then
@@ -158,19 +152,32 @@ function hide {
       _warn_or_abort "file not found: $input_path" "1" "$force_continue"
     else
       file_hash=$(_get_file_hash "$input_path")
-  
-      # encrypt file only if required
-      if [[ "$update_only_modified" -eq 0 ]] || [[ "$fsdb_file_hash" != "$file_hash" ]]; then
 
-        local args=( --homedir "$secrets_dir_keys" "--no-permission-warning" --use-agent --yes "--trust-model=always" --encrypt )
+      # encrypt file only if required
+      if [[ "$update_only_modified" -eq 0 ]] ||
+         [[ "$fsdb_file_hash" != "$file_hash" ]]; then
+
+        local args=( --homedir "$secrets_dir_keys" --use-agent --yes '--trust-model=always' --encrypt )
+
+        # SECRETS_GPG_ARMOR is expected to be empty or '1'.
+        # Empty means 'off', any other value means 'on'.
+        # See: https://github.com/sobolevn/git-secret/pull/661
+        # shellcheck disable=SC2153
+        if [[ -n "$SECRETS_GPG_ARMOR" ]] &&
+           [[ "$SECRETS_GPG_ARMOR" -ne 0 ]]; then
+          args+=( '--armor' )
+        fi
+
+        # we no longer use --no-permission-warning here in non-verbose mode, for #811
 
         # we depend on $recipients being split on whitespace
         # shellcheck disable=SC2206
         args+=( $recipients -o "$output_path" "$input_path" )
 
-        set +e   # disable 'set -e' so we can capture exit_code
+        set +e  # disable 'set -e' so we can capture exit_code
 
-     	  # see https://github.com/bats-core/bats-core#file-descriptor-3-read-this-if-bats-hangs for info about 3>&-
+     	  # For info about `3>&-` see:
+        # https://github.com/bats-core/bats-core#file-descriptor-3-read-this-if-bats-hangs
         local gpg_output
         gpg_output=$($SECRETS_GPG_COMMAND "${args[@]}" 3>&-)  # we leave stderr alone
         local exit_code=$?
@@ -179,13 +186,13 @@ function hide {
 
         local error=0
         if [[ "$exit_code" -ne 0 ]] || [[ ! -f "$output_path" ]]; then
-          error=1 
+          error=1
         fi
 
         if [[ "$error" -ne 0 ]] || [[ -n "$_SECRETS_VERBOSE" ]]; then
           if [[ -n "$gpg_output" ]]; then
             echo "$gpg_output"
-          fi  
+          fi
         fi
 
         if [[ ! -f "$output_path" ]]; then
@@ -199,7 +206,7 @@ function hide {
             chmod "$perms" "$output_path"
           fi
         fi
-  
+
         # Update file hash for future use of -m
         local key="$filename"
         local hash="$file_hash"
