@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 
-# shellcheck disable=2016
+# shellcheck disable=SC2016
 AWK_ADD_TO_GITIGNORE='
 BEGIN {
   cnt=0
@@ -33,7 +33,7 @@ function gitignore_add_pattern {
   local gitignore_file_path
 
   pattern="$1"
-  gitignore_file_path=$(_append_root_path '.gitignore')
+  gitignore_file_path=$(_prepend_root_path '.gitignore')
 
   _maybe_create_gitignore
   _gawk_inplace -v pattern="$pattern" "'$AWK_ADD_TO_GITIGNORE'" "$gitignore_file_path"
@@ -53,7 +53,7 @@ function init {
   shift $((OPTIND-1))
   [ "$1" = '--' ] && shift
 
-  if [ $# -ne 0 ]; then 
+  if [ $# -ne 0 ]; then
     _abort "init does not understand params: $*"
   fi
 
@@ -71,6 +71,7 @@ function init {
   # Create internal files:
 
   mkdir "$git_secret_dir" "$(_get_secrets_dir_keys)" "$(_get_secrets_dir_path)"
+  chmod 700 "$(_get_secrets_dir_keys)"  # for #811, set to rwx------
   touch "$(_get_secrets_dir_paths_mapping)"
 
   _message "init created: '$git_secret_dir/'"
