@@ -31,7 +31,7 @@ function remove {
     local path # absolute path
     local normalized_path # relative to .git folder
     normalized_path=$(_git_normalize_filename "$item")
-    path=$(_append_root_path "$normalized_path")
+    path=$(_prepend_root_path "$normalized_path")
 
     # Checking if file exists:
     if [[ ! -f "$path" ]]; then
@@ -53,6 +53,9 @@ function remove {
       encrypted_filename=$(_get_encrypted_filename "$path")
 
       rm "$encrypted_filename" # fail on error
+      if [[ -n "$_SECRETS_VERBOSE" ]]; then
+          _message "deleted: $encrypted_filename"
+      fi
     fi
   done
 
