@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 
-# shellcheck disable=2016
+# shellcheck disable=SC2016
 AWK_GPG_KEY_CNT='
 BEGIN { cnt=0; OFS=":"; FS=":"; }
 flag=0; $1 == "pub" { cnt++ }
@@ -77,7 +77,7 @@ function tell {
   start_key_cnt=$(get_gpg_key_count)
   for email in "${emails[@]}"; do
     _temporary_file  # note that `_temporary_file` will export `temporary_filename` var.
-    # shellcheck disable=2154
+    # shellcheck disable=SC2154
     local keyfile="$temporary_filename"
 
     # 3>&- closes fd 3 for bats, see https://github.com/bats-core/bats-core#file-descriptor-3-read-this-if-bats-hangs
@@ -86,8 +86,9 @@ function tell {
       $SECRETS_GPG_COMMAND --export -a "$email" > "$keyfile" 3>&-
       exit_code=$?
     else
-      # It means that homedir is set as an extra argument via `-d`:
-      $SECRETS_GPG_COMMAND --no-permission-warning --homedir="$homedir" \
+      # This means that homedir is set as an extra argument via `-d`:
+      # we no longer use --no-permission-warning here, for #811
+      $SECRETS_GPG_COMMAND --homedir="$homedir" \
         --export -a "$email" > "$keyfile" 3>&-
       exit_code=$?
     fi
@@ -100,7 +101,7 @@ function tell {
     fi
 
     # Importing public key to the local keyring:
-    local args=( --homedir "$secrets_dir_keys" --no-permission-warning --import "$keyfile" )
+    local args=( --homedir "$secrets_dir_keys" --import "$keyfile" )
     if [[ -z "$_SECRETS_VERBOSE" ]]; then
       $SECRETS_GPG_COMMAND "${args[@]}" > /dev/null 2>&1 3>&-
     else
