@@ -1,6 +1,6 @@
 sh -c "echo 'https://gitsecret.jfrog.io/artifactory/git-secret-apk/all/main'" >> /etc/apk/repositories
 wget -O /etc/apk/keys/git-secret-apk.rsa.pub 'https://gitsecret.jfrog.io/artifactory/api/security/keypair/public/repositories/git-secret-apk'
-apk update && apk add git-secret
+apk add --update --no-cache git-secret
 
 # Testing, that it worked:
 git secret --version
